package com.vetti.hotake.service;

import java.util.List;
import com.vetti.hotake.domain.HotakeRolesApplyInfo;
import com.vetti.hotake.domain.dto.HotakeRolesApplyStageStatisticalDto;
import com.vetti.hotake.domain.vo.HotakeRolesApplyStageVo;

/**
 * 候选人岗位申请信息Service接口
 * 
 * @author wangxiangshun
 * @date 2025-12-17
 */
public interface IHotakeRolesApplyInfoService 
{
    /**
     * 查询候选人岗位申请信息
     * 
     * @param id 候选人岗位申请信息主键
     * @return 候选人岗位申请信息
     */
    public HotakeRolesApplyInfo selectHotakeRolesApplyInfoById(Long id);

    /**
     * 查询候选人岗位申请信息列表
     * 
     * @param hotakeRolesApplyInfo 候选人岗位申请信息
     * @return 候选人岗位申请信息集合
     */
    public List<HotakeRolesApplyInfo> selectHotakeRolesApplyInfoList(HotakeRolesApplyInfo hotakeRolesApplyInfo);

    /**
     * 新增候选人岗位申请信息
     * 
     * @param hotakeRolesApplyInfo 候选人岗位申请信息
     * @return 结果
     */
    public HotakeRolesApplyInfo insertHotakeRolesApplyInfo(HotakeRolesApplyInfo hotakeRolesApplyInfo);

    /**
     * 修改候选人岗位申请信息
     * 
     * @param hotakeRolesApplyInfo 候选人岗位申请信息
     * @return 结果
     */
    public HotakeRolesApplyInfo updateHotakeRolesApplyInfo(HotakeRolesApplyInfo hotakeRolesApplyInfo);

    /**
     * 批量删除候选人岗位申请信息
     * 
     * @param ids 需要删除的候选人岗位申请信息主键集合
     * @return 结果
     */
    public int deleteHotakeRolesApplyInfoByIds(Long[] ids);

    /**
     * 删除候选人岗位申请信息信息
     * 
     * @param id 候选人岗位申请信息主键
     * @return 结果
     */
    public int deleteHotakeRolesApplyInfoById(Long id);

    /**
     * 批量新增候选人岗位申请信息
     *
     * @param hotakeRolesApplyInfoList 候选人岗位申请信息列表
     * @return 结果
     */
    public int batchInsertHotakeRolesApplyInfo(List<HotakeRolesApplyInfo> hotakeRolesApplyInfoList);

    /**
     * 修改候选人岗位申请信息
     *
     * @param stageVoList 候选人岗位申请信息
     * @return 结果
     */
    public int updateBatchEditStage(List<HotakeRolesApplyStageVo> stageVoList);

    /**
     * AI简历评分和排名系统
     *
     * @param hotakeRolesApplyInfo 候选人岗位申请信息
     * @return 候选人岗位申请信息集合
     */
    public List<HotakeRolesApplyInfo> handleAiCvScoringRankingList(HotakeRolesApplyInfo hotakeRolesApplyInfo);

    /**
     * 招聘者查看候选人匹配度
     *
     * @param hotakeRolesApplyInfo 候选人岗位申请信息
     * @return 候选人岗位申请信息集合
     */
    public HotakeRolesApplyInfo handleCandidateCompatibilityInfo(HotakeRolesApplyInfo hotakeRolesApplyInfo);

    /**
     * 岗位申请数据根据当前阶段进行统计
     *
     * @param hotakeRolesApplyInfo 候选人岗位申请信息
     * @return 岗位申请数据根据当前阶段进行统计 信息集合
     */
    public HotakeRolesApplyStageStatisticalDto handleHotakeRolesApplyStageStatistical(HotakeRolesApplyInfo hotakeRolesApplyInfo);

    /**
     * 候选人面试综合评估
     *
     * @param hotakeRolesApplyInfo 候选人岗位申请信息
     * @return 候选人岗位申请信息集合
     */
    public HotakeRolesApplyInfo handleCandidateInterviewEvaluation(HotakeRolesApplyInfo hotakeRolesApplyInfo);

}
